register

Function register 

pub fn register(profile: UbuntuPcProfile) -> RegisteredCard
Construct the exact Card for a supported Ubuntu profile.

Panics

Panics only if serialization of the closed profile enum fails.