pub fn register(profile: UbuntuPcProfile) -> RegisteredCardExpand description
Construct the exact Card for a supported Ubuntu profile.
Panics
Panics only if serialization of the closed profile enum fails.
pub fn register(profile: UbuntuPcProfile) -> RegisteredCardConstruct the exact Card for a supported Ubuntu profile.
Panics only if serialization of the closed profile enum fails.